@@ -5,7 +5,7 @@ BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 
 @lru_cache()
 def amis_templates(template_name: str = 'page.html', template_path: str = ''):
-    '''页面模板'''
+    """页面模板"""
     template_path = template_path or BASE_DIR + '/templates/' + template_name
     with open(template_path, encoding='utf8') as f:
         tmp = f.read()
